@@ -74,6 +74,11 @@ class FactDatasourceTypeEnum(Enum):
     # python中JMS类型使用的是stomp协议，如果配置的JMS类型，需要开启对应消息组件的stomp支持
     JMS = 'JMS'
     ALGORITHM = 'ALGORITHM'
+    REF = 'REF'       # 表示这个FD是关联的其他的FD
+    FTP = 'FTP'
+    S3 = 'S3'
+    NAS = 'NAS'
+    HOTFOLDER = 'HOTFOLDER'
 
 
 class JdbcTypeEnum(Enum):
