@@ -28,6 +28,15 @@ def on_request(self, protocol):
     except:
         pass
 
+    try:
+        # 在celery环境中,需要在celery的子进程中也初始化这个监听
+        # 这里要提前获取一次,便于提前加载和开启数据库连接以及FD的变化监听
+        from factdatasource import FactDatasourceProxyService
+        FactDatasourceProxyService.fd_client_proxy()
+        log.info("完成FD服务监听加载")
+    except:
+        pass
+
     body = Munch(json.loads(protocol))
 
     result: ResultVO = TriggerActor.handle_trigger(body, True)  # ResultVO
