@@ -32,7 +32,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
         target = self.fd().target
         try:
             costomer_context.set_source(source_name)
-            result = self.dao.count(index=target, doc_type=self.DEFAULT_INDEX_TYPE)
+            result = self.dao.count(index=target)
             size = 0 if result is None else result
             return size
         except Exception as e:
@@ -51,7 +51,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
         target = self.fd().target
         try:
             costomer_context.set_source(source_name)
-            result = self.dao.count(index=target, doc_type=self.DEFAULT_INDEX_TYPE)
+            result = self.dao.count(index=target)
             size = 0 if result is None else result
             return size <= 0
         except Exception as e:
@@ -72,8 +72,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
         try:
             costomer_context.set_source(source_name)
             size = size if size else 0
-            result = self.dao.simple_query(index=target, doc_type=self.DEFAULT_INDEX_TYPE, size=size,
-                                           analyze_wildcard=True)
+            result = self.dao.simple_query(index=target, size=size)
             return result
         except Exception as e:
             error = f'事实库{source_name}执行collect操作发生异常, {str(e)}'
@@ -139,8 +138,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
         try:
             log.debug(f'事实库{source_name}执行query操作SQL：{query}')
             costomer_context.set_source(source_name)
-            query_result = self.dao.query(index=target, doc_type=self.DEFAULT_INDEX_TYPE, body=query,
-                                          analyze_wildcard=True)
+            query_result = self.dao.query(index=target, body=query)
         except Exception as e:
             error = f'事实库{source_name}执行query操作SQL：{query} 发生异常, {str(e)}'
             log.error(error)
@@ -184,7 +182,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
                 primary_values_key = self.get_primary_values_key(primary_keys, result)
                 if not primary_values_key:
                     # 没设置id,只能用upsert,create要求id必填
-                    self.dao.upsert(index=table, doc_type=self.DEFAULT_INDEX_TYPE, body=result, refresh=True)
+                    self.dao.upsert(index=table, doc_type=self.DEFAULT_INDEX_TYPE, body=result, refresh='true')
                     rrr.append(Munch({"success": True}))
                     continue
 
@@ -194,7 +192,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
                                     refresh='wait_for')
                 else:
                     self.dao.create(index=table, doc_type=self.DEFAULT_INDEX_TYPE, id=primary_values_key, body=result,
-                                    refresh=True)
+                                    refresh='true')
                 rrr.append(Munch({"success": True}))
         except Exception as e:
             error = f'事实库{source_name}执行inserts操作发生异常, {str(e)}'
@@ -230,7 +228,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
 
                 # 这里有可能最后一个没有设置主键，导致跳过最后一条数据的刷新，所以这里就每条都设置刷新
                 self.dao.partial_update(index=table, doc_type=self.DEFAULT_INDEX_TYPE, id=primary_values_key,
-                                        body=result, refresh=True)
+                                        body=result, refresh='true')
                 rrr.append(Munch({"success": True}))
         except Exception as e:
             error = f'事实库{source_name}执行updates操作发生异常, {str(e)}'
@@ -269,7 +267,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
                                     refresh='wait_for')
                 else:
                     self.dao.upsert(index=table, doc_type=self.DEFAULT_INDEX_TYPE, id=primary_values_key, body=result,
-                                    refresh=True)
+                                    refresh='true')
                 rrr.append(Munch({"success":True}))
         except Exception as e:
             error = f'事实库{source_name}执行upserts操作发生异常, {str(e)}'
@@ -294,7 +292,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
                     "match_all": {}
                 }
             }
-            self.dao.delete_by_query(index=target, body=body, doc_type=self.DEFAULT_INDEX_TYPE, analyze_wildcard=True)
+            self.dao.delete_by_query(index=target, body=body)
         except Exception as e:
             error = f'事实库{source_name}执行delete_all操作发生异常, {str(e)}'
             log.error(error)
@@ -312,7 +310,7 @@ class EsFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCondit
         log.debug(f'事实库{source_name}执行delete操作SQL：{query}')
         try:
             costomer_context.set_source(source_name)
-            self.dao.delete_by_query(index=target, body=query, doc_type=self.DEFAULT_INDEX_TYPE, analyze_wildcard=True)
+            self.dao.delete_by_query(index=target, body=query)
         except Exception as e:
             error = f'事实库{source_name}执行delete操作发生异常, {str(e)}'
             log.error(error)
