@@ -1,4 +1,5 @@
 from schedule.TaskThread import TaskThread
+from libs.utils import stop_thread
 
 __actor_port = 8011
 __task_thread_cache = dict()
@@ -21,6 +22,7 @@ def registry_task_thread(task_id: int, handler, remove_old_reason: str):
 
     if old_task_thread is not None:
         old_task_thread.stop(remove_old_reason)
+        stop_thread(old_task_thread)
 
     return new_task_thread
 
@@ -36,7 +38,7 @@ def remove_task_thread(job_id: int, remove_old_reason: str):
 
     if old_task_thread is not None:
         old_task_thread.stop(remove_old_reason)
-        # 还需要调用 interrupt()
+        stop_thread(old_task_thread)
 
 
 def cancel_task_thread(job_id: int, task_id: int, is_executing: bool):
